.. toctree::
   :maxdepth: 2
   :hidden:

   self
   level_one
   specs/spec-214
   specs/dataset_extra
   specs/spec-122
   reference
   release_history

.. _data-products:

DKIST Data Products
-------------------

This section of the DKIST documentation covers the data products generated by DKIST at all processing levels and stages.
The focus is on the Level 1 data products, as these have been designed for consumption by scientists.  The Level 0
products, which are available upon request, have less of a focus on the end-user.

First Steps
-----------

* **From the start**: :ref:`level-one-data-products`.
* **FITS Specifications**: :ref:`spec-214` | :ref:`dataset_extra` | :ref:`spec-122`
* **Details**: :ref:`api-reference` | :ref:`release_history`.

Getting Around the Documentation
--------------------------------

The documentation is split up into sections:

* An introduction to Level 1 data products and how these are packaged by the DKIST Data Center.
* A detailed specification of the Level 1 FITS headers (known as DKIST Spec 214).
* A detailed specification of the dataset extra FITS headers available with Level 1 datasets.
* A detailed specification of the Level 0 FITS headers (known as DKIST Spec 122).
